@@ -1,5 +1,4 @@
 import asyncio
-
 import base64
 import getpass
 import os
@@ -12,6 +11,7 @@ import pytest
 
 import dask
 from dask.distributed import Client, wait
+import dask_kubernetes
 from dask_kubernetes import (
     KubeCluster,
     make_pod_spec,
@@ -808,3 +808,74 @@ async def test_adapt_delete(cluster, ns):
         await asyncio.sleep(0.1)
         assert time() < start + 20
     assert len(cluster.scheduler_info["workers"]) == 2
+
+
+@pytest.mark.asyncio
+async def test_auto_refresh(cluster):
+    config = {
+        "apiVersion": "v1",
+        "clusters": [
+            {
+                "cluster": {"certificate-authority-data": "", "server": ""},
+                "name": "mock_gcp_config",
+            }
+        ],
+        "contexts": [
+            {
+                "context": {
+                    "cluster": "mock_gcp_config",
+                    "user": "mock_gcp_config",
+                },
+                "name": "mock_gcp_config",
+            }
+        ],
+        "current-context": "mock_gcp_config",
+        "kind": "config",
+        "preferences": {},
+        "users": [
+            {
+                "name": "mock_gcp_config",
+                "user": {
+                    "auth-provider": {
+                        "config": {
+                            "access-token": "",
+                            "cmd-args": "--fake-arg arg",
+                            "cmd-path": f"python {TEST_DIR}/fake_gcp_auth.py",
+                            "expiry": "",
+                            "expiry-key": "{.credential.token_expiry}",
+                            "toekn-key": "{.credential.access_token}",
+                        },
+                        "name": "gcp",
+                    }
+                },
+            }
+        ],
+    }
+    config_persister = False
+
+    loader = dask_kubernetes.AutoRefreshKubeConfigLoader(
+        config_dict=config,
+        config_base_path=None,
+        config_persister=config_persister,
+    )
+
+    await loader.load_gcp_token()
+    # Check that we get back a token
+    assert loader.token == f"Bearer {'0' * 137}"
+
+    next_expire = loader.token_expire_ts
+    for task in asyncio.all_tasks():
+        if task.get_name() == "dask_auth_auto_refresh":
+            await asyncio.wait_for(task, 10)
+
+    # Ensure that our token expiration timer was refreshed
+    assert loader.token_expire_ts > next_expire
+
+    # Ensure refresh task was re-created
+    for task in asyncio.all_tasks():
+        if task.get_name() == "dask_auth_auto_refresh":
+            loader.auto_refresh = False
+            await asyncio.wait_for(task, 10)
+            break
+    else:
+        assert False
