@@ -62,33 +62,6 @@ def test_container_resources_config(docker_image, loop):
         assert "cpu" not in pod.spec.containers[0].resources.requests
 
 
-def test_extra_container_config_merge(docker_image, loop):
-    """
-    Test that our container config merging process works recursively fine
-    """
-    with KubeCluster(
-        make_pod_spec(
-            docker_image,
-            extra_container_config={
-                "env": [{"name": "BOO", "value": "FOO"}],
-                "args": ["last-item"],
-            },
-        ),
-        loop=loop,
-        n_workers=0,
-        env={"TEST": "HI"},
-    ) as cluster:
-
-        pod = cluster.pod_template
-
-        assert pod.spec.containers[0].env == [
-            {"name": "TEST", "value": "HI"},
-            {"name": "BOO", "value": "FOO"},
-        ]
-
-        assert pod.spec.containers[0].args[-1] == "last-item"
-
-
 def test_extra_container_config_merge(docker_image, loop):
     """
     Test that our container config merging process works recursively fine
@@ -144,3 +117,35 @@ def test_make_pod_from_dict():
     assert pod.spec.restart_policy == "Never"
     assert pod.spec.containers[0].security_context.privileged
     assert pod.spec.containers[0].security_context.capabilities.add == ["SYS_ADMIN"]
+
+
+def test_make_pod_from_dict_default_container_name():
+    d = {
+        "kind": "Pod",
+        "metadata": {"labels": {"app": "dask", "dask.org/component": "dask-worker"}},
+        "spec": {
+            "containers": [
+                {
+                    "args": [
+                        "dask-worker",
+                        "$(DASK_SCHEDULER_ADDRESS)",
+                        "--nthreads",
+                        "1",
+                    ],
+                    "image": "image-name",
+                    "securityContext": {
+                        "capabilities": {"add": ["SYS_ADMIN"]},
+                        "privileged": True,
+                    },
+                },
+                {"image": "image-name2", "name": "sidecar"},
+                {"image": "image-name3"},
+            ],
+            "restartPolicy": "Never",
+        },
+    }
+
+    pod = make_pod_from_dict(d)
+    assert pod.spec.containers[0].name == "dask-0"
+    assert pod.spec.containers[1].name == "sidecar"
+    assert pod.spec.containers[2].name == "dask-2"
