@@ -94,7 +94,9 @@ async def port_forward_service(service_name, namespace, remote_port, local_port=
             f"{namespace}",
             f"service/{service_name}",
             f"{local_port}:{remote_port}",
-        ]
+        ],
+        stdout=subprocess.DEVNULL,
+        stderr=subprocess.DEVNULL,
     )
     time.sleep(1)
     finalize(kproc, kproc.kill)
@@ -104,10 +106,10 @@ async def port_forward_service(service_name, namespace, remote_port, local_port=
     raise ConnectionError("kubectl port forward failed")
 
 
-async def is_comm_open(ip, port, retries=30):
+async def is_comm_open(ip, port, retries=10):
     while retries > 0:
         try:
-            async with Client(f"tcp://{ip}:{port}", asynchronous=True, timeout=0.5):
+            async with Client(f"tcp://{ip}:{port}", asynchronous=True, timeout=2):
                 return True
         except Exception:
             time.sleep(0.5)
